# metafab

Metafab - JavaScript client for metafab
 Complete MetaFab API references and guides can be found at: https://trymetafab.com
This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.1
- Build package: org.openapitools.codegen.languages.JavascriptClientCodegen
For more information, please visit [https://trymetafab.com](https://trymetafab.com)

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

To publish the library as a [npm](https://www.npmjs.com/), please follow the procedure in ["Publishing npm packages"](https://docs.npmjs.com/getting-started/publishing-npm-packages).

Then install it via:

```shell
npm install metafab --save
```

Finally, you need to build the module:

```shell
npm run build
```

##### Local development

To use the library locally without publishing to a remote npm registry, first install the dependencies by changing into the directory containing `package.json` (and this README). Let's call this `JAVASCRIPT_CLIENT_DIR`. Then run:

```shell
npm install
```

Next, [link](https://docs.npmjs.com/cli/link) it globally in npm with the following, also from `JAVASCRIPT_CLIENT_DIR`:

```shell
npm link
```

To use the link you just defined in your project, switch to the directory you want to use your metafab from, and run:

```shell
npm link /path/to/<JAVASCRIPT_CLIENT_DIR>
```

Finally, you need to build the module:

```shell
npm run build
```

#### git

If the library is hosted at a git repository, e.g.https://github.com/GIT_USER_ID/GIT_REPO_ID
then install it via:

```shell
    npm install GIT_USER_ID/GIT_REPO_ID --save
```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var Metafab = require('metafab');


var api = new Metafab.ContractsApi()
var xAuthorization = game_sk_02z4Mv3c85Ig0gNowY9Dq0N2kjb1xwzr27ArLE0669RrRI6dLf822iPO26K1p1FP; // {String} The `secretKey` of the authenticating game.
var createContractRequest = new Metafab.CreateContractRequest(); // {CreateContractRequest} 
api.createContract(xAuthorization, createContractRequest).then(function(data) {
  console.log('API called successfully. Returned data: ' + data);
}, function(error) {
  console.error(error);
});


```

## Documentation for API Endpoints

All URIs are relative to *https://api.trymetafab.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Metafab.ContractsApi* | [**createContract**](docs/ContractsApi.md#createContract) | **POST** /v1/contracts | Create custom contract
*Metafab.ContractsApi* | [**getContracts**](docs/ContractsApi.md#getContracts) | **GET** /v1/contracts | Get contracts
*Metafab.ContractsApi* | [**readContract**](docs/ContractsApi.md#readContract) | **GET** /v1/contracts/{contractId}/reads | Read contract data
*Metafab.ContractsApi* | [**writeContract**](docs/ContractsApi.md#writeContract) | **POST** /v1/contracts/{contractId}/writes | Write contract data
*Metafab.CurrenciesApi* | [**batchTransferCurrency**](docs/CurrenciesApi.md#batchTransferCurrency) | **POST** /v1/currencies/{currencyId}/batchTransfers | Batch transfer currency
*Metafab.CurrenciesApi* | [**burnCurrency**](docs/CurrenciesApi.md#burnCurrency) | **POST** /v1/currencies/{currencyId}/burns | Burn currency
*Metafab.CurrenciesApi* | [**createCurrency**](docs/CurrenciesApi.md#createCurrency) | **POST** /v1/currencies | Create currency
*Metafab.CurrenciesApi* | [**getCurrencies**](docs/CurrenciesApi.md#getCurrencies) | **GET** /v1/currencies | Get currencies
*Metafab.CurrenciesApi* | [**getCurrencyBalances**](docs/CurrenciesApi.md#getCurrencyBalances) | **GET** /v1/currencies/{currencyId}/balances | Get currency balance
*Metafab.CurrenciesApi* | [**getCurrencyFees**](docs/CurrenciesApi.md#getCurrencyFees) | **GET** /v1/currencies/{currencyId}/fees | Get currency fees
*Metafab.CurrenciesApi* | [**mintCurrency**](docs/CurrenciesApi.md#mintCurrency) | **POST** /v1/currencies/{currencyId}/mints | Mint currency
*Metafab.CurrenciesApi* | [**setCurrencyFees**](docs/CurrenciesApi.md#setCurrencyFees) | **POST** /v1/currencies/{currencyId}/fees | Set currency fees
*Metafab.CurrenciesApi* | [**transferCurrency**](docs/CurrenciesApi.md#transferCurrency) | **POST** /v1/currencies/{currencyId}/transfers | Transfer currency
*Metafab.GamesApi* | [**authGame**](docs/GamesApi.md#authGame) | **GET** /v1/games | Authenticate game
*Metafab.GamesApi* | [**createGame**](docs/GamesApi.md#createGame) | **POST** /v1/games | Create game
*Metafab.GamesApi* | [**updateGame**](docs/GamesApi.md#updateGame) | **PATCH** /v1/games/{gameId} | Update game
*Metafab.PlayersApi* | [**authPlayer**](docs/PlayersApi.md#authPlayer) | **GET** /v1/players | Authenticate player
*Metafab.PlayersApi* | [**createPlayer**](docs/PlayersApi.md#createPlayer) | **POST** /v1/players | Create player
*Metafab.PlayersApi* | [**updatePlayer**](docs/PlayersApi.md#updatePlayer) | **PATCH** /v1/players/{playerId} | Update player
*Metafab.TransactionsApi* | [**getTransaction**](docs/TransactionsApi.md#getTransaction) | **GET** /v1/transactions/{transactionId} | Get transaction
*Metafab.WalletsApi* | [**getWalletBalances**](docs/WalletsApi.md#getWalletBalances) | **GET** /v1/wallets/{walletId}/balances | Get wallet balances
*Metafab.WalletsApi* | [**getWalletTransactions**](docs/WalletsApi.md#getWalletTransactions) | **GET** /v1/wallets/{walletId}/transactions | Get wallet transactions


## Documentation for Models

 - [Metafab.AuthGame200Response](docs/AuthGame200Response.md)
 - [Metafab.AuthGame200ResponseAllOf](docs/AuthGame200ResponseAllOf.md)
 - [Metafab.AuthGame200ResponseAllOf1](docs/AuthGame200ResponseAllOf1.md)
 - [Metafab.AuthPlayer200Response](docs/AuthPlayer200Response.md)
 - [Metafab.BatchTransferCurrencyRequest](docs/BatchTransferCurrencyRequest.md)
 - [Metafab.BurnCurrencyRequest](docs/BurnCurrencyRequest.md)
 - [Metafab.ContractModel](docs/ContractModel.md)
 - [Metafab.CreateContractRequest](docs/CreateContractRequest.md)
 - [Metafab.CreateCurrency200Response](docs/CreateCurrency200Response.md)
 - [Metafab.CreateCurrency200ResponseAllOf](docs/CreateCurrency200ResponseAllOf.md)
 - [Metafab.CreateCurrency200ResponseAllOfContract](docs/CreateCurrency200ResponseAllOfContract.md)
 - [Metafab.CreateCurrency200ResponseAllOfContractAllOf](docs/CreateCurrency200ResponseAllOfContractAllOf.md)
 - [Metafab.CreateCurrencyRequest](docs/CreateCurrencyRequest.md)
 - [Metafab.CreateGameRequest](docs/CreateGameRequest.md)
 - [Metafab.CreatePlayerRequest](docs/CreatePlayerRequest.md)
 - [Metafab.CurrencyModel](docs/CurrencyModel.md)
 - [Metafab.GameModel](docs/GameModel.md)
 - [Metafab.GetCurrencies200ResponseInner](docs/GetCurrencies200ResponseInner.md)
 - [Metafab.GetCurrencies200ResponseInnerAllOf](docs/GetCurrencies200ResponseInnerAllOf.md)
 - [Metafab.GetCurrencyFees200Response](docs/GetCurrencyFees200Response.md)
 - [Metafab.MintCurrencyRequest](docs/MintCurrencyRequest.md)
 - [Metafab.PlayerModel](docs/PlayerModel.md)
 - [Metafab.SetCurrencyFeesRequest](docs/SetCurrencyFeesRequest.md)
 - [Metafab.TransactionModel](docs/TransactionModel.md)
 - [Metafab.TransferCurrencyRequest](docs/TransferCurrencyRequest.md)
 - [Metafab.UpdateGameRequest](docs/UpdateGameRequest.md)
 - [Metafab.UpdatePlayerRequest](docs/UpdatePlayerRequest.md)
 - [Metafab.WalletModel](docs/WalletModel.md)
 - [Metafab.WriteContractRequest](docs/WriteContractRequest.md)


## Documentation for Authorization



### basicAuth

- **Type**: HTTP basic authentication

