"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _BatchTransferCurrencyRequest = _interopRequireDefault(require("../model/BatchTransferCurrencyRequest"));

var _BurnCurrencyRequest = _interopRequireDefault(require("../model/BurnCurrencyRequest"));

var _CreateCurrency200Response = _interopRequireDefault(require("../model/CreateCurrency200Response"));

var _CreateCurrencyRequest = _interopRequireDefault(require("../model/CreateCurrencyRequest"));

var _GetCurrencies200ResponseInner = _interopRequireDefault(require("../model/GetCurrencies200ResponseInner"));

var _GetCurrencyFees200Response = _interopRequireDefault(require("../model/GetCurrencyFees200Response"));

var _MintCurrencyRequest = _interopRequireDefault(require("../model/MintCurrencyRequest"));

var _SetCurrencyFeesRequest = _interopRequireDefault(require("../model/SetCurrencyFeesRequest"));

var _TransactionModel = _interopRequireDefault(require("../model/TransactionModel"));

var _TransferCurrencyRequest = _interopRequireDefault(require("../model/TransferCurrencyRequest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

/**
* Currencies service.
* @module api/CurrenciesApi
* @version 1.0.1
*/
var CurrenciesApi = /*#__PURE__*/function () {
  /**
  * Constructs a new CurrenciesApi. 
  * @alias module:api/CurrenciesApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function CurrenciesApi(apiClient) {
    _classCallCheck(this, CurrenciesApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Batch transfer currency
   * Transfers multiple amounts of currency to multiple provided wallet addresses or wallet addresses associated with the provided walletIds. You may also provide a combination of addresses and walletIds in one request, the proper receipients will be automatically determined, with `addresses` getting `amounts` order priority first. Optional references may be included for the transfer. References are useful for identifying transfers intended to pay for items, trades, services and more.
   * @param {String} currencyId Any currency id within the MetaFab ecosystem.
   * @param {String} xAuthorization The `secretKey` of a specific game or the `accessToken` of a specific player.
   * @param {String} xPassword The password of the authenticating game or player. Required to decrypt and perform blockchain transactions with the game or player primary wallet.
   * @param {module:model/BatchTransferCurrencyRequest} batchTransferCurrencyRequest 
   * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/TransactionModel} and HTTP response
   */


  _createClass(CurrenciesApi, [{
    key: "batchTransferCurrencyWithHttpInfo",
    value: function batchTransferCurrencyWithHttpInfo(currencyId, xAuthorization, xPassword, batchTransferCurrencyRequest) {
      var postBody = batchTransferCurrencyRequest; // verify the required parameter 'currencyId' is set

      if (currencyId === undefined || currencyId === null) {
        throw new Error("Missing the required parameter 'currencyId' when calling batchTransferCurrency");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling batchTransferCurrency");
      } // verify the required parameter 'xPassword' is set


      if (xPassword === undefined || xPassword === null) {
        throw new Error("Missing the required parameter 'xPassword' when calling batchTransferCurrency");
      } // verify the required parameter 'batchTransferCurrencyRequest' is set


      if (batchTransferCurrencyRequest === undefined || batchTransferCurrencyRequest === null) {
        throw new Error("Missing the required parameter 'batchTransferCurrencyRequest' when calling batchTransferCurrency");
      }

      var pathParams = {
        'currencyId': currencyId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization,
        'X-Password': xPassword
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _TransactionModel["default"];
      return this.apiClient.callApi('/v1/currencies/{currencyId}/batchTransfers', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Batch transfer currency
     * Transfers multiple amounts of currency to multiple provided wallet addresses or wallet addresses associated with the provided walletIds. You may also provide a combination of addresses and walletIds in one request, the proper receipients will be automatically determined, with `addresses` getting `amounts` order priority first. Optional references may be included for the transfer. References are useful for identifying transfers intended to pay for items, trades, services and more.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of a specific game or the `accessToken` of a specific player.
     * @param {String} xPassword The password of the authenticating game or player. Required to decrypt and perform blockchain transactions with the game or player primary wallet.
     * @param {module:model/BatchTransferCurrencyRequest} batchTransferCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/TransactionModel}
     */

  }, {
    key: "batchTransferCurrency",
    value: function batchTransferCurrency(currencyId, xAuthorization, xPassword, batchTransferCurrencyRequest) {
      return this.batchTransferCurrencyWithHttpInfo(currencyId, xAuthorization, xPassword, batchTransferCurrencyRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Burn currency
     * Removes (burns) the provided amount of currency from the authenticating game or players wallet. The currency amount is permanently removed from the circulating supply of the currency.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of a specific game or the `accessToken` of a specific player.
     * @param {String} xPassword The password of the authenticating game or player. Required to decrypt and perform blockchain transactions with the game or player primary wallet.
     * @param {module:model/BurnCurrencyRequest} burnCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/TransactionModel} and HTTP response
     */

  }, {
    key: "burnCurrencyWithHttpInfo",
    value: function burnCurrencyWithHttpInfo(currencyId, xAuthorization, xPassword, burnCurrencyRequest) {
      var postBody = burnCurrencyRequest; // verify the required parameter 'currencyId' is set

      if (currencyId === undefined || currencyId === null) {
        throw new Error("Missing the required parameter 'currencyId' when calling burnCurrency");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling burnCurrency");
      } // verify the required parameter 'xPassword' is set


      if (xPassword === undefined || xPassword === null) {
        throw new Error("Missing the required parameter 'xPassword' when calling burnCurrency");
      } // verify the required parameter 'burnCurrencyRequest' is set


      if (burnCurrencyRequest === undefined || burnCurrencyRequest === null) {
        throw new Error("Missing the required parameter 'burnCurrencyRequest' when calling burnCurrency");
      }

      var pathParams = {
        'currencyId': currencyId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization,
        'X-Password': xPassword
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _TransactionModel["default"];
      return this.apiClient.callApi('/v1/currencies/{currencyId}/burns', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Burn currency
     * Removes (burns) the provided amount of currency from the authenticating game or players wallet. The currency amount is permanently removed from the circulating supply of the currency.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of a specific game or the `accessToken` of a specific player.
     * @param {String} xPassword The password of the authenticating game or player. Required to decrypt and perform blockchain transactions with the game or player primary wallet.
     * @param {module:model/BurnCurrencyRequest} burnCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/TransactionModel}
     */

  }, {
    key: "burnCurrency",
    value: function burnCurrency(currencyId, xAuthorization, xPassword, burnCurrencyRequest) {
      return this.burnCurrencyWithHttpInfo(currencyId, xAuthorization, xPassword, burnCurrencyRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Create currency
     * Creates a new game currency and deploys an ERC20 token contract on behalf of the authenticating game's primary wallet. The deployed ERC20 contract is preconfigured to fully support bridging across blockchains, batched transfers and gasless transactions on any supported blockchain as well as full support for gasless transactions from player managed wallets.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {String} xPassword The password of the authenticating game. Required to decrypt and perform blockchain transactions with the game primary wallet.
     * @param {module:model/CreateCurrencyRequest} createCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/CreateCurrency200Response} and HTTP response
     */

  }, {
    key: "createCurrencyWithHttpInfo",
    value: function createCurrencyWithHttpInfo(xAuthorization, xPassword, createCurrencyRequest) {
      var postBody = createCurrencyRequest; // verify the required parameter 'xAuthorization' is set

      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling createCurrency");
      } // verify the required parameter 'xPassword' is set


      if (xPassword === undefined || xPassword === null) {
        throw new Error("Missing the required parameter 'xPassword' when calling createCurrency");
      } // verify the required parameter 'createCurrencyRequest' is set


      if (createCurrencyRequest === undefined || createCurrencyRequest === null) {
        throw new Error("Missing the required parameter 'createCurrencyRequest' when calling createCurrency");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization,
        'X-Password': xPassword
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _CreateCurrency200Response["default"];
      return this.apiClient.callApi('/v1/currencies', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Create currency
     * Creates a new game currency and deploys an ERC20 token contract on behalf of the authenticating game's primary wallet. The deployed ERC20 contract is preconfigured to fully support bridging across blockchains, batched transfers and gasless transactions on any supported blockchain as well as full support for gasless transactions from player managed wallets.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {String} xPassword The password of the authenticating game. Required to decrypt and perform blockchain transactions with the game primary wallet.
     * @param {module:model/CreateCurrencyRequest} createCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/CreateCurrency200Response}
     */

  }, {
    key: "createCurrency",
    value: function createCurrency(xAuthorization, xPassword, createCurrencyRequest) {
      return this.createCurrencyWithHttpInfo(xAuthorization, xPassword, createCurrencyRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Get currencies
     * Returns an array of active currencies for the game associated with the provided `X-Game-Key`.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link Array.<module:model/GetCurrencies200ResponseInner>} and HTTP response
     */

  }, {
    key: "getCurrenciesWithHttpInfo",
    value: function getCurrenciesWithHttpInfo(xGameKey) {
      var postBody = null; // verify the required parameter 'xGameKey' is set

      if (xGameKey === undefined || xGameKey === null) {
        throw new Error("Missing the required parameter 'xGameKey' when calling getCurrencies");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {
        'X-Game-Key': xGameKey
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [_GetCurrencies200ResponseInner["default"]];
      return this.apiClient.callApi('/v1/currencies', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Get currencies
     * Returns an array of active currencies for the game associated with the provided `X-Game-Key`.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link Array.<module:model/GetCurrencies200ResponseInner>}
     */

  }, {
    key: "getCurrencies",
    value: function getCurrencies(xGameKey) {
      return this.getCurrenciesWithHttpInfo(xGameKey).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Get currency balance
     * Returns the current currency balance of the provided wallet address or or the wallet address associated with the provided walletId.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {Object} opts Optional parameters
     * @param {String} opts.address A valid EVM based address. For example, `0x39cb70F972E0EE920088AeF97Dbe5c6251a9c25D`.
     * @param {String} opts.walletId Any wallet id within the MetaFab ecosystem.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link Number} and HTTP response
     */

  }, {
    key: "getCurrencyBalancesWithHttpInfo",
    value: function getCurrencyBalancesWithHttpInfo(currencyId, opts) {
      opts = opts || {};
      var postBody = null; // verify the required parameter 'currencyId' is set

      if (currencyId === undefined || currencyId === null) {
        throw new Error("Missing the required parameter 'currencyId' when calling getCurrencyBalances");
      }

      var pathParams = {
        'currencyId': currencyId
      };
      var queryParams = {
        'address': opts['address'],
        'walletId': opts['walletId']
      };
      var headerParams = {};
      var formParams = {};
      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = 'Number';
      return this.apiClient.callApi('/v1/currencies/{currencyId}/balances', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Get currency balance
     * Returns the current currency balance of the provided wallet address or or the wallet address associated with the provided walletId.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {Object} opts Optional parameters
     * @param {String} opts.address A valid EVM based address. For example, `0x39cb70F972E0EE920088AeF97Dbe5c6251a9c25D`.
     * @param {String} opts.walletId Any wallet id within the MetaFab ecosystem.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link Number}
     */

  }, {
    key: "getCurrencyBalances",
    value: function getCurrencyBalances(currencyId, opts) {
      return this.getCurrencyBalancesWithHttpInfo(currencyId, opts).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Get currency fees
     * Returns the current fee recipient address and fees of the currency for the provided currencyId. Fees are only applicable for gasless transactions performed by default by players.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/GetCurrencyFees200Response} and HTTP response
     */

  }, {
    key: "getCurrencyFeesWithHttpInfo",
    value: function getCurrencyFeesWithHttpInfo(currencyId) {
      var postBody = null; // verify the required parameter 'currencyId' is set

      if (currencyId === undefined || currencyId === null) {
        throw new Error("Missing the required parameter 'currencyId' when calling getCurrencyFees");
      }

      var pathParams = {
        'currencyId': currencyId
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _GetCurrencyFees200Response["default"];
      return this.apiClient.callApi('/v1/currencies/{currencyId}/fees', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Get currency fees
     * Returns the current fee recipient address and fees of the currency for the provided currencyId. Fees are only applicable for gasless transactions performed by default by players.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/GetCurrencyFees200Response}
     */

  }, {
    key: "getCurrencyFees",
    value: function getCurrencyFees(currencyId) {
      return this.getCurrencyFeesWithHttpInfo(currencyId).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Mint currency
     * Creates (mints) the provided amount of currency  to the provided wallet address or wallet address associated with the provided walletId.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {String} xPassword The password of the authenticating game. Required to decrypt and perform blockchain transactions with the game primary wallet.
     * @param {module:model/MintCurrencyRequest} mintCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/TransactionModel} and HTTP response
     */

  }, {
    key: "mintCurrencyWithHttpInfo",
    value: function mintCurrencyWithHttpInfo(currencyId, xAuthorization, xPassword, mintCurrencyRequest) {
      var postBody = mintCurrencyRequest; // verify the required parameter 'currencyId' is set

      if (currencyId === undefined || currencyId === null) {
        throw new Error("Missing the required parameter 'currencyId' when calling mintCurrency");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling mintCurrency");
      } // verify the required parameter 'xPassword' is set


      if (xPassword === undefined || xPassword === null) {
        throw new Error("Missing the required parameter 'xPassword' when calling mintCurrency");
      } // verify the required parameter 'mintCurrencyRequest' is set


      if (mintCurrencyRequest === undefined || mintCurrencyRequest === null) {
        throw new Error("Missing the required parameter 'mintCurrencyRequest' when calling mintCurrency");
      }

      var pathParams = {
        'currencyId': currencyId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization,
        'X-Password': xPassword
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _TransactionModel["default"];
      return this.apiClient.callApi('/v1/currencies/{currencyId}/mints', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Mint currency
     * Creates (mints) the provided amount of currency  to the provided wallet address or wallet address associated with the provided walletId.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {String} xPassword The password of the authenticating game. Required to decrypt and perform blockchain transactions with the game primary wallet.
     * @param {module:model/MintCurrencyRequest} mintCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/TransactionModel}
     */

  }, {
    key: "mintCurrency",
    value: function mintCurrency(currencyId, xAuthorization, xPassword, mintCurrencyRequest) {
      return this.mintCurrencyWithHttpInfo(currencyId, xAuthorization, xPassword, mintCurrencyRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Set currency fees
     * Sets the recipient address, basis points, fixed amount and cap amount for a currency's fees.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {String} xPassword The password of the authenticating game. Required to decrypt and perform blockchain transactions with the game primary wallet.
     * @param {module:model/SetCurrencyFeesRequest} setCurrencyFeesRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/TransactionModel} and HTTP response
     */

  }, {
    key: "setCurrencyFeesWithHttpInfo",
    value: function setCurrencyFeesWithHttpInfo(currencyId, xAuthorization, xPassword, setCurrencyFeesRequest) {
      var postBody = setCurrencyFeesRequest; // verify the required parameter 'currencyId' is set

      if (currencyId === undefined || currencyId === null) {
        throw new Error("Missing the required parameter 'currencyId' when calling setCurrencyFees");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling setCurrencyFees");
      } // verify the required parameter 'xPassword' is set


      if (xPassword === undefined || xPassword === null) {
        throw new Error("Missing the required parameter 'xPassword' when calling setCurrencyFees");
      } // verify the required parameter 'setCurrencyFeesRequest' is set


      if (setCurrencyFeesRequest === undefined || setCurrencyFeesRequest === null) {
        throw new Error("Missing the required parameter 'setCurrencyFeesRequest' when calling setCurrencyFees");
      }

      var pathParams = {
        'currencyId': currencyId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization,
        'X-Password': xPassword
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _TransactionModel["default"];
      return this.apiClient.callApi('/v1/currencies/{currencyId}/fees', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Set currency fees
     * Sets the recipient address, basis points, fixed amount and cap amount for a currency's fees.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {String} xPassword The password of the authenticating game. Required to decrypt and perform blockchain transactions with the game primary wallet.
     * @param {module:model/SetCurrencyFeesRequest} setCurrencyFeesRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/TransactionModel}
     */

  }, {
    key: "setCurrencyFees",
    value: function setCurrencyFees(currencyId, xAuthorization, xPassword, setCurrencyFeesRequest) {
      return this.setCurrencyFeesWithHttpInfo(currencyId, xAuthorization, xPassword, setCurrencyFeesRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Transfer currency
     * Transfers an amount of currency to the provided wallet address or wallet address associated with the provided walletId. If you want to transfer to multiple wallets with different amounts and optional references in one API request, please see the Batch transfer currency documentation.  An optional reference may be included for the transfer. References are useful for identifying transfers intended to pay for items, trades, services and more.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of a specific game or the `accessToken` of a specific player.
     * @param {String} xPassword The password of the authenticating game or player. Required to decrypt and perform blockchain transactions with the game or player primary wallet.
     * @param {module:model/TransferCurrencyRequest} transferCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/TransactionModel} and HTTP response
     */

  }, {
    key: "transferCurrencyWithHttpInfo",
    value: function transferCurrencyWithHttpInfo(currencyId, xAuthorization, xPassword, transferCurrencyRequest) {
      var postBody = transferCurrencyRequest; // verify the required parameter 'currencyId' is set

      if (currencyId === undefined || currencyId === null) {
        throw new Error("Missing the required parameter 'currencyId' when calling transferCurrency");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling transferCurrency");
      } // verify the required parameter 'xPassword' is set


      if (xPassword === undefined || xPassword === null) {
        throw new Error("Missing the required parameter 'xPassword' when calling transferCurrency");
      } // verify the required parameter 'transferCurrencyRequest' is set


      if (transferCurrencyRequest === undefined || transferCurrencyRequest === null) {
        throw new Error("Missing the required parameter 'transferCurrencyRequest' when calling transferCurrency");
      }

      var pathParams = {
        'currencyId': currencyId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization,
        'X-Password': xPassword
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _TransactionModel["default"];
      return this.apiClient.callApi('/v1/currencies/{currencyId}/transfers', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Transfer currency
     * Transfers an amount of currency to the provided wallet address or wallet address associated with the provided walletId. If you want to transfer to multiple wallets with different amounts and optional references in one API request, please see the Batch transfer currency documentation.  An optional reference may be included for the transfer. References are useful for identifying transfers intended to pay for items, trades, services and more.
     * @param {String} currencyId Any currency id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of a specific game or the `accessToken` of a specific player.
     * @param {String} xPassword The password of the authenticating game or player. Required to decrypt and perform blockchain transactions with the game or player primary wallet.
     * @param {module:model/TransferCurrencyRequest} transferCurrencyRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/TransactionModel}
     */

  }, {
    key: "transferCurrency",
    value: function transferCurrency(currencyId, xAuthorization, xPassword, transferCurrencyRequest) {
      return this.transferCurrencyWithHttpInfo(currencyId, xAuthorization, xPassword, transferCurrencyRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
  }]);

  return CurrenciesApi;
}();

exports["default"] = CurrenciesApi;