"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _AuthGame200Response = _interopRequireDefault(require("../model/AuthGame200Response"));

var _CreateGameRequest = _interopRequireDefault(require("../model/CreateGameRequest"));

var _GameModel = _interopRequireDefault(require("../model/GameModel"));

var _UpdateGameRequest = _interopRequireDefault(require("../model/UpdateGameRequest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

/**
* Games service.
* @module api/GamesApi
* @version 1.0.1
*/
var GamesApi = /*#__PURE__*/function () {
  /**
  * Constructs a new GamesApi. 
  * @alias module:api/GamesApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function GamesApi(apiClient) {
    _classCallCheck(this, GamesApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Authenticate game
   * Returns an existing game object containing authorization keys and credentials when provided a valid email (in place of username) and password login using Basic Auth.
   * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AuthGame200Response} and HTTP response
   */


  _createClass(GamesApi, [{
    key: "authGameWithHttpInfo",
    value: function authGameWithHttpInfo() {
      var postBody = null;
      var pathParams = {};
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['basicAuth'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _AuthGame200Response["default"];
      return this.apiClient.callApi('/v1/games', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Authenticate game
     * Returns an existing game object containing authorization keys and credentials when provided a valid email (in place of username) and password login using Basic Auth.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AuthGame200Response}
     */

  }, {
    key: "authGame",
    value: function authGame() {
      return this.authGameWithHttpInfo().then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Create game
     * Create a new game. A game is the root entity required for all API interactions. Contracts, currencies, items and more are deployed by games, player accounts are created and registered to games, etc.  To use any of MetaFab's services, you must first create a game through this endpoint.  **Game creation is limited during our closed beta. Please contact ArkDev#4501 on Discord to be a part of our beta.**
     * @param {module:model/CreateGameRequest} createGameRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AuthGame200Response} and HTTP response
     */

  }, {
    key: "createGameWithHttpInfo",
    value: function createGameWithHttpInfo(createGameRequest) {
      var postBody = createGameRequest; // verify the required parameter 'createGameRequest' is set

      if (createGameRequest === undefined || createGameRequest === null) {
        throw new Error("Missing the required parameter 'createGameRequest' when calling createGame");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _AuthGame200Response["default"];
      return this.apiClient.callApi('/v1/games', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Create game
     * Create a new game. A game is the root entity required for all API interactions. Contracts, currencies, items and more are deployed by games, player accounts are created and registered to games, etc.  To use any of MetaFab's services, you must first create a game through this endpoint.  **Game creation is limited during our closed beta. Please contact ArkDev#4501 on Discord to be a part of our beta.**
     * @param {module:model/CreateGameRequest} createGameRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AuthGame200Response}
     */

  }, {
    key: "createGame",
    value: function createGame(createGameRequest) {
      return this.createGameWithHttpInfo(createGameRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Update game
     * Update various fields specific to a game. Such as changing its password, resetting its published or secret key, or updating its RPCs.
     * @param {String} gameId Any game id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {module:model/UpdateGameRequest} updateGameRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/GameModel} and HTTP response
     */

  }, {
    key: "updateGameWithHttpInfo",
    value: function updateGameWithHttpInfo(gameId, xAuthorization, updateGameRequest) {
      var postBody = updateGameRequest; // verify the required parameter 'gameId' is set

      if (gameId === undefined || gameId === null) {
        throw new Error("Missing the required parameter 'gameId' when calling updateGame");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling updateGame");
      } // verify the required parameter 'updateGameRequest' is set


      if (updateGameRequest === undefined || updateGameRequest === null) {
        throw new Error("Missing the required parameter 'updateGameRequest' when calling updateGame");
      }

      var pathParams = {
        'gameId': gameId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _GameModel["default"];
      return this.apiClient.callApi('/v1/games/{gameId}', 'PATCH', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Update game
     * Update various fields specific to a game. Such as changing its password, resetting its published or secret key, or updating its RPCs.
     * @param {String} gameId Any game id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {module:model/UpdateGameRequest} updateGameRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/GameModel}
     */

  }, {
    key: "updateGame",
    value: function updateGame(gameId, xAuthorization, updateGameRequest) {
      return this.updateGameWithHttpInfo(gameId, xAuthorization, updateGameRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
  }]);

  return GamesApi;
}();

exports["default"] = GamesApi;