"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _AuthPlayer200Response = _interopRequireDefault(require("../model/AuthPlayer200Response"));

var _CreatePlayerRequest = _interopRequireDefault(require("../model/CreatePlayerRequest"));

var _PlayerModel = _interopRequireDefault(require("../model/PlayerModel"));

var _UpdatePlayerRequest = _interopRequireDefault(require("../model/UpdatePlayerRequest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

/**
* Players service.
* @module api/PlayersApi
* @version 1.0.1
*/
var PlayersApi = /*#__PURE__*/function () {
  /**
  * Constructs a new PlayersApi. 
  * @alias module:api/PlayersApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function PlayersApi(apiClient) {
    _classCallCheck(this, PlayersApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Authenticate player
   * Returns an existing player object containing access token, wallet, and other details for a game when provided a valid username and password login using Basic Auth.
   * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
   * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AuthPlayer200Response} and HTTP response
   */


  _createClass(PlayersApi, [{
    key: "authPlayerWithHttpInfo",
    value: function authPlayerWithHttpInfo(xGameKey) {
      var postBody = null; // verify the required parameter 'xGameKey' is set

      if (xGameKey === undefined || xGameKey === null) {
        throw new Error("Missing the required parameter 'xGameKey' when calling authPlayer");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {
        'X-Game-Key': xGameKey
      };
      var formParams = {};
      var authNames = ['basicAuth'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _AuthPlayer200Response["default"];
      return this.apiClient.callApi('/v1/players', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Authenticate player
     * Returns an existing player object containing access token, wallet, and other details for a game when provided a valid username and password login using Basic Auth.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AuthPlayer200Response}
     */

  }, {
    key: "authPlayer",
    value: function authPlayer(xGameKey) {
      return this.authPlayerWithHttpInfo(xGameKey).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Create player
     * Create a new player for a game. Players are automatically associated with an internally managed wallet.  Player access tokens can be used to directly interact with any MetaFab managed contracts, currencies, items collections, marketplaces and more. Player interactions are also gasless by default, completely removing all crypto friction for players to engage with your MetaFab supported games.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @param {module:model/CreatePlayerRequest} createPlayerRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AuthPlayer200Response} and HTTP response
     */

  }, {
    key: "createPlayerWithHttpInfo",
    value: function createPlayerWithHttpInfo(xGameKey, createPlayerRequest) {
      var postBody = createPlayerRequest; // verify the required parameter 'xGameKey' is set

      if (xGameKey === undefined || xGameKey === null) {
        throw new Error("Missing the required parameter 'xGameKey' when calling createPlayer");
      } // verify the required parameter 'createPlayerRequest' is set


      if (createPlayerRequest === undefined || createPlayerRequest === null) {
        throw new Error("Missing the required parameter 'createPlayerRequest' when calling createPlayer");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {
        'X-Game-Key': xGameKey
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _AuthPlayer200Response["default"];
      return this.apiClient.callApi('/v1/players', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Create player
     * Create a new player for a game. Players are automatically associated with an internally managed wallet.  Player access tokens can be used to directly interact with any MetaFab managed contracts, currencies, items collections, marketplaces and more. Player interactions are also gasless by default, completely removing all crypto friction for players to engage with your MetaFab supported games.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @param {module:model/CreatePlayerRequest} createPlayerRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AuthPlayer200Response}
     */

  }, {
    key: "createPlayer",
    value: function createPlayer(xGameKey, createPlayerRequest) {
      return this.createPlayerWithHttpInfo(xGameKey, createPlayerRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Update player
     * Update various fields specific to a player. Such as changing its password and resetting its access token.
     * @param {String} playerId Any player id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `accessToken` of the authenticating player.
     * @param {module:model/UpdatePlayerRequest} updatePlayerRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/PlayerModel} and HTTP response
     */

  }, {
    key: "updatePlayerWithHttpInfo",
    value: function updatePlayerWithHttpInfo(playerId, xAuthorization, updatePlayerRequest) {
      var postBody = updatePlayerRequest; // verify the required parameter 'playerId' is set

      if (playerId === undefined || playerId === null) {
        throw new Error("Missing the required parameter 'playerId' when calling updatePlayer");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling updatePlayer");
      } // verify the required parameter 'updatePlayerRequest' is set


      if (updatePlayerRequest === undefined || updatePlayerRequest === null) {
        throw new Error("Missing the required parameter 'updatePlayerRequest' when calling updatePlayer");
      }

      var pathParams = {
        'playerId': playerId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _PlayerModel["default"];
      return this.apiClient.callApi('/v1/players/{playerId}', 'PATCH', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Update player
     * Update various fields specific to a player. Such as changing its password and resetting its access token.
     * @param {String} playerId Any player id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `accessToken` of the authenticating player.
     * @param {module:model/UpdatePlayerRequest} updatePlayerRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/PlayerModel}
     */

  }, {
    key: "updatePlayer",
    value: function updatePlayer(playerId, xAuthorization, updatePlayerRequest) {
      return this.updatePlayerWithHttpInfo(playerId, xAuthorization, updatePlayerRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
  }]);

  return PlayersApi;
}();

exports["default"] = PlayersApi;