"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _TransactionModel = _interopRequireDefault(require("../model/TransactionModel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

/**
* Wallets service.
* @module api/WalletsApi
* @version 1.0.1
*/
var WalletsApi = /*#__PURE__*/function () {
  /**
  * Constructs a new WalletsApi. 
  * @alias module:api/WalletsApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function WalletsApi(apiClient) {
    _classCallCheck(this, WalletsApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Get wallet balances
   * Returns the current native token balance for all chains supported by MetaFab for the provided walletId. This includes balances like Eth, Matic and other native tokens from chains MetaFab supports.
   * @param {String} walletId Any wallet id within the MetaFab ecosystem.
   * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link Object.<String, {String: Number}>} and HTTP response
   */


  _createClass(WalletsApi, [{
    key: "getWalletBalancesWithHttpInfo",
    value: function getWalletBalancesWithHttpInfo(walletId) {
      var postBody = null; // verify the required parameter 'walletId' is set

      if (walletId === undefined || walletId === null) {
        throw new Error("Missing the required parameter 'walletId' when calling getWalletBalances");
      }

      var pathParams = {
        'walletId': walletId
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = {
        'String': 'Number'
      };
      return this.apiClient.callApi('/v1/wallets/{walletId}/balances', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Get wallet balances
     * Returns the current native token balance for all chains supported by MetaFab for the provided walletId. This includes balances like Eth, Matic and other native tokens from chains MetaFab supports.
     * @param {String} walletId Any wallet id within the MetaFab ecosystem.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link Object.<String, {String: Number}>}
     */

  }, {
    key: "getWalletBalances",
    value: function getWalletBalances(walletId) {
      return this.getWalletBalancesWithHttpInfo(walletId).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Get wallet transactions
     * Returns an array of MetaFab initiated transactions performed by the provided walletId. Transactions returned are ordered chronologically from newest to oldest.
     * @param {String} walletId Any wallet id within the MetaFab ecosystem.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link Array.<module:model/TransactionModel>} and HTTP response
     */

  }, {
    key: "getWalletTransactionsWithHttpInfo",
    value: function getWalletTransactionsWithHttpInfo(walletId) {
      var postBody = null; // verify the required parameter 'walletId' is set

      if (walletId === undefined || walletId === null) {
        throw new Error("Missing the required parameter 'walletId' when calling getWalletTransactions");
      }

      var pathParams = {
        'walletId': walletId
      };
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [_TransactionModel["default"]];
      return this.apiClient.callApi('/v1/wallets/{walletId}/transactions', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Get wallet transactions
     * Returns an array of MetaFab initiated transactions performed by the provided walletId. Transactions returned are ordered chronologically from newest to oldest.
     * @param {String} walletId Any wallet id within the MetaFab ecosystem.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link Array.<module:model/TransactionModel>}
     */

  }, {
    key: "getWalletTransactions",
    value: function getWalletTransactions(walletId) {
      return this.getWalletTransactionsWithHttpInfo(walletId).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
  }]);

  return WalletsApi;
}();

exports["default"] = WalletsApi;