"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _ContractModel = _interopRequireDefault(require("../model/ContractModel"));

var _TransactionModel = _interopRequireDefault(require("../model/TransactionModel"));

var _V1ContractsContractIdWritesPostRequest = _interopRequireDefault(require("../model/V1ContractsContractIdWritesPostRequest"));

var _V1ContractsGetRequest = _interopRequireDefault(require("../model/V1ContractsGetRequest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

/**
* Contracts service.
* @module metafab-javascript/ContractsApi
* @version 1.0.0
*/
var ContractsApi = /*#__PURE__*/function () {
  /**
  * Constructs a new ContractsApi. 
  * @alias module:metafab-javascript/ContractsApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function ContractsApi(apiClient) {
    _classCallCheck(this, ContractsApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Read contract data
   * Oftentimes you'll want to query and retrieve some data from a contract. This is incredibly easy to do for any contract deployed through MetaFab.  Using this endpoint, you can get the data returned by any readable function listed in a contracts ABI. This could be things like querying the totalSupply of a currency contract, the number of owners of an items contract, and more.
   * @param {String} contractId Any contract id within the MetaFab ecosystem.
   * @param {String} func A contract function name. This can be any valid function from the the ABI of the contract you are interacting with. For example, `balanceOf`.
   * @param {Object} opts Optional parameters
   * @param {String} opts.args A comma seperated list of basic data type arguments. This is optional and only necessary if the function being invoked requires arguments per the contract ABI. For example, `123,\"Hello\",false`.
   * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link Object} and HTTP response
   */


  _createClass(ContractsApi, [{
    key: "v1ContractsContractIdReadsGetWithHttpInfo",
    value: function v1ContractsContractIdReadsGetWithHttpInfo(contractId, func, opts) {
      opts = opts || {};
      var postBody = null; // verify the required parameter 'contractId' is set

      if (contractId === undefined || contractId === null) {
        throw new Error("Missing the required parameter 'contractId' when calling v1ContractsContractIdReadsGet");
      } // verify the required parameter 'func' is set


      if (func === undefined || func === null) {
        throw new Error("Missing the required parameter 'func' when calling v1ContractsContractIdReadsGet");
      }

      var pathParams = {
        'contractId': contractId
      };
      var queryParams = {
        'func': func,
        'args': opts['args']
      };
      var headerParams = {};
      var formParams = {};
      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = Object;
      return this.apiClient.callApi('/v1/contracts/{contractId}/reads', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Read contract data
     * Oftentimes you'll want to query and retrieve some data from a contract. This is incredibly easy to do for any contract deployed through MetaFab.  Using this endpoint, you can get the data returned by any readable function listed in a contracts ABI. This could be things like querying the totalSupply of a currency contract, the number of owners of an items contract, and more.
     * @param {String} contractId Any contract id within the MetaFab ecosystem.
     * @param {String} func A contract function name. This can be any valid function from the the ABI of the contract you are interacting with. For example, `balanceOf`.
     * @param {Object} opts Optional parameters
     * @param {String} opts.args A comma seperated list of basic data type arguments. This is optional and only necessary if the function being invoked requires arguments per the contract ABI. For example, `123,\"Hello\",false`.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link Object}
     */

  }, {
    key: "v1ContractsContractIdReadsGet",
    value: function v1ContractsContractIdReadsGet(contractId, func, opts) {
      return this.v1ContractsContractIdReadsGetWithHttpInfo(contractId, func, opts).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Write contract data
     * MetaFab's convenience endpoints for contract interactions may not be flexible enough depending on your use case. For these situations, you can interact with contracts and create transactions directly.  Using this endpoint, you can execute a transaction for any writeable contract method as defined in the contract's ABI for the MetaFab contractId provided. Both Games and Player resources have authority to use this endpoint to execute transactions against any valid MetaFab contractId.  Additionally, MetaFab will automatically attempt to perform a gasless transaction for players interacting with a contract through this endpoint. Gasless transactions by players through this endpoint will only work if the target contract was deployed through MetaFab or supports MetaFab's ERC2771 trusted forwarder contract.
     * @param {String} contractId Any contract id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of a specific game or the `accessToken` of a specific player.
     * @param {String} xPassword The password of the authenticating game or player. Required to decrypt and perform blockchain transactions with the game or player primary wallet.
     * @param {module:model/V1ContractsContractIdWritesPostRequest} v1ContractsContractIdWritesPostRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/TransactionModel} and HTTP response
     */

  }, {
    key: "v1ContractsContractIdWritesPostWithHttpInfo",
    value: function v1ContractsContractIdWritesPostWithHttpInfo(contractId, xAuthorization, xPassword, v1ContractsContractIdWritesPostRequest) {
      var postBody = v1ContractsContractIdWritesPostRequest; // verify the required parameter 'contractId' is set

      if (contractId === undefined || contractId === null) {
        throw new Error("Missing the required parameter 'contractId' when calling v1ContractsContractIdWritesPost");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling v1ContractsContractIdWritesPost");
      } // verify the required parameter 'xPassword' is set


      if (xPassword === undefined || xPassword === null) {
        throw new Error("Missing the required parameter 'xPassword' when calling v1ContractsContractIdWritesPost");
      } // verify the required parameter 'v1ContractsContractIdWritesPostRequest' is set


      if (v1ContractsContractIdWritesPostRequest === undefined || v1ContractsContractIdWritesPostRequest === null) {
        throw new Error("Missing the required parameter 'v1ContractsContractIdWritesPostRequest' when calling v1ContractsContractIdWritesPost");
      }

      var pathParams = {
        'contractId': contractId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization,
        'X-Password': xPassword
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _TransactionModel["default"];
      return this.apiClient.callApi('/v1/contracts/{contractId}/writes', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Write contract data
     * MetaFab's convenience endpoints for contract interactions may not be flexible enough depending on your use case. For these situations, you can interact with contracts and create transactions directly.  Using this endpoint, you can execute a transaction for any writeable contract method as defined in the contract's ABI for the MetaFab contractId provided. Both Games and Player resources have authority to use this endpoint to execute transactions against any valid MetaFab contractId.  Additionally, MetaFab will automatically attempt to perform a gasless transaction for players interacting with a contract through this endpoint. Gasless transactions by players through this endpoint will only work if the target contract was deployed through MetaFab or supports MetaFab's ERC2771 trusted forwarder contract.
     * @param {String} contractId Any contract id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of a specific game or the `accessToken` of a specific player.
     * @param {String} xPassword The password of the authenticating game or player. Required to decrypt and perform blockchain transactions with the game or player primary wallet.
     * @param {module:model/V1ContractsContractIdWritesPostRequest} v1ContractsContractIdWritesPostRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/TransactionModel}
     */

  }, {
    key: "v1ContractsContractIdWritesPost",
    value: function v1ContractsContractIdWritesPost(contractId, xAuthorization, xPassword, v1ContractsContractIdWritesPostRequest) {
      return this.v1ContractsContractIdWritesPostWithHttpInfo(contractId, xAuthorization, xPassword, v1ContractsContractIdWritesPostRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Get contracts
     * Returns an array of active contracts deployed by the game associated with the provided `X-Game-Key`.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link Array.<module:model/ContractModel>} and HTTP response
     */

  }, {
    key: "v1ContractsGetWithHttpInfo",
    value: function v1ContractsGetWithHttpInfo(xGameKey) {
      var postBody = null; // verify the required parameter 'xGameKey' is set

      if (xGameKey === undefined || xGameKey === null) {
        throw new Error("Missing the required parameter 'xGameKey' when calling v1ContractsGet");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {
        'X-Game-Key': xGameKey
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [_ContractModel["default"]];
      return this.apiClient.callApi('/v1/contracts', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Get contracts
     * Returns an array of active contracts deployed by the game associated with the provided `X-Game-Key`.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link Array.<module:model/ContractModel>}
     */

  }, {
    key: "v1ContractsGet",
    value: function v1ContractsGet(xGameKey) {
      return this.v1ContractsGetWithHttpInfo(xGameKey).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Create custom contract
     * Create a MetaFab custom contract entry from an existing contract address and contract abi. This allows the game and players belonging to the authenticated game to interact with the contract's read and write functions through MetaFab's read and write contract endpoints.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {module:model/V1ContractsGetRequest} v1ContractsGetRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/ContractModel} and HTTP response
     */

  }, {
    key: "v1ContractsPostWithHttpInfo",
    value: function v1ContractsPostWithHttpInfo(xAuthorization, v1ContractsGetRequest) {
      var postBody = v1ContractsGetRequest; // verify the required parameter 'xAuthorization' is set

      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling v1ContractsPost");
      } // verify the required parameter 'v1ContractsGetRequest' is set


      if (v1ContractsGetRequest === undefined || v1ContractsGetRequest === null) {
        throw new Error("Missing the required parameter 'v1ContractsGetRequest' when calling v1ContractsPost");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _ContractModel["default"];
      return this.apiClient.callApi('/v1/contracts', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Create custom contract
     * Create a MetaFab custom contract entry from an existing contract address and contract abi. This allows the game and players belonging to the authenticated game to interact with the contract's read and write functions through MetaFab's read and write contract endpoints.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {module:model/V1ContractsGetRequest} v1ContractsGetRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/ContractModel}
     */

  }, {
    key: "v1ContractsPost",
    value: function v1ContractsPost(xAuthorization, v1ContractsGetRequest) {
      return this.v1ContractsPostWithHttpInfo(xAuthorization, v1ContractsGetRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
  }]);

  return ContractsApi;
}();

exports["default"] = ContractsApi;