"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _GameModel = _interopRequireDefault(require("../model/GameModel"));

var _V1GamesGameIdPatchRequest = _interopRequireDefault(require("../model/V1GamesGameIdPatchRequest"));

var _V1GamesGet200Response = _interopRequireDefault(require("../model/V1GamesGet200Response"));

var _V1GamesGetRequest = _interopRequireDefault(require("../model/V1GamesGetRequest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

/**
* Games service.
* @module metafab-javascript/GamesApi
* @version 1.0.0
*/
var GamesApi = /*#__PURE__*/function () {
  /**
  * Constructs a new GamesApi. 
  * @alias module:metafab-javascript/GamesApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function GamesApi(apiClient) {
    _classCallCheck(this, GamesApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Update game
   * Update various fields specific to a game. Such as changing its password, resetting its published or secret key, or updating its RPCs.
   * @param {String} gameId Any game id within the MetaFab ecosystem.
   * @param {String} xAuthorization The `secretKey` of the authenticating game.
   * @param {module:model/V1GamesGameIdPatchRequest} v1GamesGameIdPatchRequest 
   * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/GameModel} and HTTP response
   */


  _createClass(GamesApi, [{
    key: "v1GamesGameIdPatchWithHttpInfo",
    value: function v1GamesGameIdPatchWithHttpInfo(gameId, xAuthorization, v1GamesGameIdPatchRequest) {
      var postBody = v1GamesGameIdPatchRequest; // verify the required parameter 'gameId' is set

      if (gameId === undefined || gameId === null) {
        throw new Error("Missing the required parameter 'gameId' when calling v1GamesGameIdPatch");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling v1GamesGameIdPatch");
      } // verify the required parameter 'v1GamesGameIdPatchRequest' is set


      if (v1GamesGameIdPatchRequest === undefined || v1GamesGameIdPatchRequest === null) {
        throw new Error("Missing the required parameter 'v1GamesGameIdPatchRequest' when calling v1GamesGameIdPatch");
      }

      var pathParams = {
        'gameId': gameId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _GameModel["default"];
      return this.apiClient.callApi('/v1/games/{gameId}', 'PATCH', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Update game
     * Update various fields specific to a game. Such as changing its password, resetting its published or secret key, or updating its RPCs.
     * @param {String} gameId Any game id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `secretKey` of the authenticating game.
     * @param {module:model/V1GamesGameIdPatchRequest} v1GamesGameIdPatchRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/GameModel}
     */

  }, {
    key: "v1GamesGameIdPatch",
    value: function v1GamesGameIdPatch(gameId, xAuthorization, v1GamesGameIdPatchRequest) {
      return this.v1GamesGameIdPatchWithHttpInfo(gameId, xAuthorization, v1GamesGameIdPatchRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Authenticate game
     * Returns an existing game object containing authorization keys and credentials when provided a valid email (in place of username) and password login using Basic Auth.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/V1GamesGet200Response} and HTTP response
     */

  }, {
    key: "v1GamesGetWithHttpInfo",
    value: function v1GamesGetWithHttpInfo() {
      var postBody = null;
      var pathParams = {};
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = ['basicAuth'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _V1GamesGet200Response["default"];
      return this.apiClient.callApi('/v1/games', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Authenticate game
     * Returns an existing game object containing authorization keys and credentials when provided a valid email (in place of username) and password login using Basic Auth.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/V1GamesGet200Response}
     */

  }, {
    key: "v1GamesGet",
    value: function v1GamesGet() {
      return this.v1GamesGetWithHttpInfo().then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Create game
     * Create a new game. A game is the root entity required for all API interactions. Contracts, currencies, items and more are deployed by games, player accounts are created and registered to games, etc.  To use any of MetaFab's services, you must first create a game through this endpoint.  **Game creation is limited during our closed beta. Please contact ArkDev#4501 on Discord to be a part of our beta.**
     * @param {module:model/V1GamesGetRequest} v1GamesGetRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/V1GamesGet200Response} and HTTP response
     */

  }, {
    key: "v1GamesPostWithHttpInfo",
    value: function v1GamesPostWithHttpInfo(v1GamesGetRequest) {
      var postBody = v1GamesGetRequest; // verify the required parameter 'v1GamesGetRequest' is set

      if (v1GamesGetRequest === undefined || v1GamesGetRequest === null) {
        throw new Error("Missing the required parameter 'v1GamesGetRequest' when calling v1GamesPost");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {};
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _V1GamesGet200Response["default"];
      return this.apiClient.callApi('/v1/games', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Create game
     * Create a new game. A game is the root entity required for all API interactions. Contracts, currencies, items and more are deployed by games, player accounts are created and registered to games, etc.  To use any of MetaFab's services, you must first create a game through this endpoint.  **Game creation is limited during our closed beta. Please contact ArkDev#4501 on Discord to be a part of our beta.**
     * @param {module:model/V1GamesGetRequest} v1GamesGetRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/V1GamesGet200Response}
     */

  }, {
    key: "v1GamesPost",
    value: function v1GamesPost(v1GamesGetRequest) {
      return this.v1GamesPostWithHttpInfo(v1GamesGetRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
  }]);

  return GamesApi;
}();

exports["default"] = GamesApi;