"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _ApiClient = _interopRequireDefault(require("../ApiClient"));

var _PlayerModel = _interopRequireDefault(require("../model/PlayerModel"));

var _V1PlayersGet200Response = _interopRequireDefault(require("../model/V1PlayersGet200Response"));

var _V1PlayersGetRequest = _interopRequireDefault(require("../model/V1PlayersGetRequest"));

var _V1PlayersPlayerIdPatchRequest = _interopRequireDefault(require("../model/V1PlayersPlayerIdPatchRequest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

/**
* Players service.
* @module metafab-javascript/PlayersApi
* @version 1.0.0
*/
var PlayersApi = /*#__PURE__*/function () {
  /**
  * Constructs a new PlayersApi. 
  * @alias module:metafab-javascript/PlayersApi
  * @class
  * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
  * default to {@link module:ApiClient#instance} if unspecified.
  */
  function PlayersApi(apiClient) {
    _classCallCheck(this, PlayersApi);

    this.apiClient = apiClient || _ApiClient["default"].instance;
  }
  /**
   * Authenticate player
   * Returns an existing player object containing access token, wallet, and other details for a game when provided a valid username and password login using Basic Auth.
   * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
   * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/V1PlayersGet200Response} and HTTP response
   */


  _createClass(PlayersApi, [{
    key: "v1PlayersGetWithHttpInfo",
    value: function v1PlayersGetWithHttpInfo(xGameKey) {
      var postBody = null; // verify the required parameter 'xGameKey' is set

      if (xGameKey === undefined || xGameKey === null) {
        throw new Error("Missing the required parameter 'xGameKey' when calling v1PlayersGet");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {
        'X-Game-Key': xGameKey
      };
      var formParams = {};
      var authNames = ['basicAuth'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = _V1PlayersGet200Response["default"];
      return this.apiClient.callApi('/v1/players', 'GET', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Authenticate player
     * Returns an existing player object containing access token, wallet, and other details for a game when provided a valid username and password login using Basic Auth.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/V1PlayersGet200Response}
     */

  }, {
    key: "v1PlayersGet",
    value: function v1PlayersGet(xGameKey) {
      return this.v1PlayersGetWithHttpInfo(xGameKey).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Update player
     * Update various fields specific to a player. Such as changing its password and resetting its access token.
     * @param {String} playerId Any player id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `accessToken` of the authenticating player.
     * @param {module:model/V1PlayersPlayerIdPatchRequest} v1PlayersPlayerIdPatchRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/PlayerModel} and HTTP response
     */

  }, {
    key: "v1PlayersPlayerIdPatchWithHttpInfo",
    value: function v1PlayersPlayerIdPatchWithHttpInfo(playerId, xAuthorization, v1PlayersPlayerIdPatchRequest) {
      var postBody = v1PlayersPlayerIdPatchRequest; // verify the required parameter 'playerId' is set

      if (playerId === undefined || playerId === null) {
        throw new Error("Missing the required parameter 'playerId' when calling v1PlayersPlayerIdPatch");
      } // verify the required parameter 'xAuthorization' is set


      if (xAuthorization === undefined || xAuthorization === null) {
        throw new Error("Missing the required parameter 'xAuthorization' when calling v1PlayersPlayerIdPatch");
      } // verify the required parameter 'v1PlayersPlayerIdPatchRequest' is set


      if (v1PlayersPlayerIdPatchRequest === undefined || v1PlayersPlayerIdPatchRequest === null) {
        throw new Error("Missing the required parameter 'v1PlayersPlayerIdPatchRequest' when calling v1PlayersPlayerIdPatch");
      }

      var pathParams = {
        'playerId': playerId
      };
      var queryParams = {};
      var headerParams = {
        'X-Authorization': xAuthorization
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _PlayerModel["default"];
      return this.apiClient.callApi('/v1/players/{playerId}', 'PATCH', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Update player
     * Update various fields specific to a player. Such as changing its password and resetting its access token.
     * @param {String} playerId Any player id within the MetaFab ecosystem.
     * @param {String} xAuthorization The `accessToken` of the authenticating player.
     * @param {module:model/V1PlayersPlayerIdPatchRequest} v1PlayersPlayerIdPatchRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/PlayerModel}
     */

  }, {
    key: "v1PlayersPlayerIdPatch",
    value: function v1PlayersPlayerIdPatch(playerId, xAuthorization, v1PlayersPlayerIdPatchRequest) {
      return this.v1PlayersPlayerIdPatchWithHttpInfo(playerId, xAuthorization, v1PlayersPlayerIdPatchRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
    /**
     * Create player
     * Create a new player for a game. Players are automatically associated with an internally managed wallet.  Player access tokens can be used to directly interact with any MetaFab managed contracts, currencies, items collections, marketplaces and more. Player interactions are also gasless by default, completely removing all crypto friction for players to engage with your MetaFab supported games.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @param {module:model/V1PlayersGetRequest} v1PlayersGetRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/V1PlayersGet200Response} and HTTP response
     */

  }, {
    key: "v1PlayersPostWithHttpInfo",
    value: function v1PlayersPostWithHttpInfo(xGameKey, v1PlayersGetRequest) {
      var postBody = v1PlayersGetRequest; // verify the required parameter 'xGameKey' is set

      if (xGameKey === undefined || xGameKey === null) {
        throw new Error("Missing the required parameter 'xGameKey' when calling v1PlayersPost");
      } // verify the required parameter 'v1PlayersGetRequest' is set


      if (v1PlayersGetRequest === undefined || v1PlayersGetRequest === null) {
        throw new Error("Missing the required parameter 'v1PlayersGetRequest' when calling v1PlayersPost");
      }

      var pathParams = {};
      var queryParams = {};
      var headerParams = {
        'X-Game-Key': xGameKey
      };
      var formParams = {};
      var authNames = [];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = _V1PlayersGet200Response["default"];
      return this.apiClient.callApi('/v1/players', 'POST', pathParams, queryParams, headerParams, formParams, postBody, authNames, contentTypes, accepts, returnType, null);
    }
    /**
     * Create player
     * Create a new player for a game. Players are automatically associated with an internally managed wallet.  Player access tokens can be used to directly interact with any MetaFab managed contracts, currencies, items collections, marketplaces and more. Player interactions are also gasless by default, completely removing all crypto friction for players to engage with your MetaFab supported games.
     * @param {String} xGameKey The `publishedKey` of a specific game. This can be shared or included in game clients, websites, etc.
     * @param {module:model/V1PlayersGetRequest} v1PlayersGetRequest 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/V1PlayersGet200Response}
     */

  }, {
    key: "v1PlayersPost",
    value: function v1PlayersPost(xGameKey, v1PlayersGetRequest) {
      return this.v1PlayersPostWithHttpInfo(xGameKey, v1PlayersGetRequest).then(function (response_and_data) {
        return response_and_data.data;
      });
    }
  }]);

  return PlayersApi;
}();

exports["default"] = PlayersApi;